"""Utilities to help building MkDocs documentations."""

import os
import sys

from universal_build import build_utils

PIPENV_RUN = "pipenv run"


def install_build_env() -> None:
    """Installs a new virtual environment via pipenv."""
    build_utils.run("pipenv --rm")
    build_utils.run(
        f"pipenv install --dev --python={sys.executable} --skip-lock --site-packages",
        exit_on_error=True,
    )


def lint_markdown() -> None:
    """Run markdownlint on markdown documentation."""
    build_utils.log("Run linters and style checks:")

    config_file_arg = ""
    if os.path.exists(".markdown-lint.yml"):
        config_file_arg = "--config='.markdown-lint.yml'"

    build_utils.run(f"markdownlint {config_file_arg} ./docs", exit_on_error=True)


def build_mkdocs(command_prefix: str = PIPENV_RUN) -> None:
    """Build mkdocs markdown documentation.

    Args:
        command_prefix (str, optional): Prefix to use for all commands. Defaults to `pipenv run`.
    """
    build_utils.run(f"{command_prefix} mkdocs build", exit_on_error=True)


def deploy_gh_pages(command_prefix: str = PIPENV_RUN) -> None:
    """Deploy mkdocs documentation to Github pages.

    Args:
        command_prefix (str, optional): Prefix to use for all commands. Defaults to `pipenv run`.
    """
    build_utils.log("Deploy documentation to Github pages:")
    build_utils.run(
        f"{command_prefix} mkdocs gh-deploy --clean", exit_on_error=True, timeout=120
    )


def run_dev_mode(port: int = 8001, command_prefix: str = PIPENV_RUN) -> None:
    """Run mkdocs development server.

    Args:
        port (int, optional): Port to use for mkdocs development server. Defaults to 8001.
        command_prefix (str, optional): Prefix to use for all commands. Defaults to `pipenv run`.
    """
    build_utils.log(f"Run docs in development mode (http://localhost:{port}):")
    build_utils.run(
        f"{command_prefix} mkdocs serve --dev-addr 0.0.0.0:{port}", exit_on_error=True
    )



#!/usr/bin/env python

import os
import re
from glob import glob
from os.path import basename, splitext

from setuptools import find_packages, setup  # type: ignore

# Package meta-data.
NAME = "universal-build"
MAIN_PACKAGE = "universal_build"  # Change if main package != NAME
DESCRIPTION = "Universal build utilities for containerized build pipelines."
URL = "https://github.com/ml-tooling/universal-build"
EMAIL = "team@mltooling.org"
AUTHOR = "ML Tooling Team"
LICENSE = "MIT"
REQUIRES_PYTHON = ">=3.6"
VERSION = None  # Only set version if you like to overwrite the version in _about.py

PWD = os.path.abspath(os.path.dirname(__file__))

# Import the README and use it as the long-description.
with open(os.path.join(PWD, "README.md"), encoding="utf-8") as f:
    long_description = f.read()

# Extract the version from the _about.py module.
if not VERSION:
    with open(os.path.join(PWD, "src", MAIN_PACKAGE, "_about.py")) as f:  # type: ignore
        VERSION = re.findall(r"__version__\s*=\s*\"(.+)\"", f.read())[0]

# Where the magic happens:
setup(
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type="text/markdown",
    author=AUTHOR,
    author_email=EMAIL,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    license=LICENSE,
    packages=find_packages(where="src", exclude=("tests", "test", "examples", "docs")),
    package_dir={"": "src"},
    py_modules=[splitext(basename(path))[0] for path in glob("src/*.py")],
    zip_safe=False,
    install_requires=["pipenv"],
    # deprecated: dependency_links=dependency_links,
    extras_require={
        # TODO: Add all extras (e.g. for build and test) here:
        # extras can be installed via: pip install package[dev]
        "dev": [
            "setuptools",
            "wheel",
            "twine",
            "flake8",
            "pytest",
            "pytest-mock",
            "pytest-cov",
            "mypy",
            "mypy",
            "black",
            "pydocstyle",
            "isort",
            "lazydocs",
        ],
    },
    include_package_data=True,
    package_data={
        # If there are data files included in your packages that need to be
        # 'sample': ['package_data.dat'],
    },
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Programming Language :: Python :: Implementation :: CPython",
        "Topic :: Software Development :: Libraries",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    project_urls={
        "Changelog": URL + "/releases",
        "Issue Tracker": URL + "/issues",
        "Documentation": URL + "#documentation",
        "Source": URL,
    },
    entry_points={"console_scripts": [f"{NAME}={MAIN_PACKAGE}._cli:app"]},
    keywords=[
        # eg: 'keyword1', 'keyword2', 'keyword3',
    ],
)
